@@ -39,6 +39,13 @@ fmt2descr = dict( zip(typ_tab[0], typ_tab[5]) )
 typ2np    = dict( zip(typ_tab[1], typ_tab[2]) )
 typ2descr = dict( zip(typ_tab[1], typ_tab[5]) )
 
+fmt2descr[1794]  = 'CHAR8'
+fmt2descr[3842]  = 'CHAR16'
+fmt2descr[7938]  = 'CHAR32'
+fmt2descr[12034] = 'CHAR48'
+fmt2descr[16130] = 'CHAR64'
+fmt2descr[18178] = 'CHAR72'
+
 # /usr/ads/codes
 #  objects
 obj_name = {1 : 'Diagnostic', 2: 'List', 3: 'Device', 4: 'ParamSet', \
@@ -78,3 +85,14 @@ unit_d = { \
   112:'+10V/16b', 113:'+-5V/655', 114:'+-10V/65', 115:'+5V/6553', 116:'+10V/655', \
   117:'nanosec', 118:'amu', 119:'pct', 120:'MHz' \
 }
+
+
+def type_len(dfmt):
+
+    if dfmt in fmt2len.keys(): # char variable
+        type_len = fmt2len[dfmt]
+    else: # numerical variable
+        sfmt = fmt2struc[dfmt]
+        type_len = np.dtype(sfmt).itemsize
+
+    return type_len
