@@ -199,7 +199,7 @@ class SFREAD:
         return rdata
 
 
-    def gettimebase(self, obj):
+    def gettimebase(self, obj, tbeg=None, tend=None):
         """
         Reads the timebase of a given SIG, SGR or AB
         """
@@ -211,15 +211,15 @@ class SFREAD:
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         if otyp == TimeBase:
-            return self.getobject(obj)
+            return self.getobject(obj, tbeg=tbeg, tend=tend)
         elif otyp in (SignalGroup, Signal, AreaBase):
             for rel in sfo.relations:
                 if self.sfh[rel].obj_type == TimeBase:
-                    return self.getobject(rel)
+                    return self.getobject(rel, tbeg=tbeg, tend=tend)
         return None
 
 
-    def getareabase(self, obj):
+    def getareabase(self, obj, tbeg=None, tend=None):
         """
         Reads the areabase of a given SIG or SGR
         """
@@ -231,11 +231,11 @@ class SFREAD:
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         if otyp == AreaBase:
-            return self.getobject(obj)
+            return self.getobject(obj, tbeg=tbeg, tend=tend)
         elif otyp in (SignalGroup, Signal):
             for rel in sfo.relations:
                 if self.sfh[rel].obj_type == AreaBase:
-                    return self.getobject(rel)
+                    return self.getobject(rel, tbeg=tbeg, tend=tend)
         return None
 
 
@@ -266,13 +266,19 @@ class SFREAD:
             if tbeg is None:
                 tbeg = 0.
             tb = self.gettimebase(obj)
+            if tb is None: # AB with no time dependence
+                logger.warning('%s has no Timebase associated, returning full array', obj)
+                return self.getobject(obj)
             jt_beg, jt_end = tb.searchsorted((tbeg, tend))
-            if otyp in (Signal, TimeBase) or self.time_last(obj):
+            if otyp in (Signal, TimeBase, AreaBase) or self.time_last(obj):
                 return self.getobject(obj, nbeg=jt_beg, nend=jt_end)
             elif self.time_first(obj):
                 return self.getobject(obj)[jt_beg: jt_end]
+#            elif otyp == AreaBase:
+#                print(self.getobject(obj).shape)
+                return self.getobject(obj)[jt_beg: jt_end]
             else:
-                logger.error('tbeg, tend keywords supported only when time is first or last dim')
+                logger.error('Object %s: tbeg, tend keywords supported only when time is first or last dim', obj)
                 return None
 
         if otyp in (SignalGroup, Signal):
@@ -304,7 +310,7 @@ class SFREAD:
                 type_len = np.dtype(sfmt).itemsize
                 addr = sfo.address
                 bytlen = np.prod(shape_arr) * type_len
-                if otyp in (Signal, TimeBase) or self.time_last(obj):
+                if otyp in (Signal, TimeBase, AreaBase) or self.time_last(obj):
                     if nbeg is None:
                         nbeg = 0
                     else:
@@ -476,6 +482,12 @@ class SFREAD:
             if dfmt in sfdics.fmt2len.keys(): # char variable
                 dlen = sfdics.fmt2len[dfmt]
                 bytlen = n_items * dlen
+                meta.dmin = buf[j0  : j0+1]
+                meta.dmax = buf[j0+1: j0+2]
+                if len(meta.dmin) == 0:
+                    meta.dmin = b' '
+                if len(meta.dmax) == 0:
+                    meta.dmax = b' '
                 data = np.chararray((n_items,), itemsize=dlen, buffer=buf[j0+2: j0+2+bytlen])
                 dj0 = 8 * ( (bytlen + 9)//8 )
                 j0 += dj0
@@ -483,11 +495,15 @@ class SFREAD:
                 sfmt = sfdics.fmt2struc[dfmt]
                 val_len = n_items + 2
                 bytlen = val_len * np.dtype(sfmt).itemsize
-                if dfmt == 7: # logical, bug if n_items > 1?
+                if dfmt == LOGICAL: # logical, bug if n_items > 1?
+                    meta.dmin = unpack(sfmt, buf[j0  : j0+1])[0]
+                    meta.dmax = unpack(sfmt, buf[j0+3: j0+4])[0]
                     data = unpack(sfmt, buf[j0+5: j0+6])[0]
                 else:
                     data = np.ndarray((val_len, ), '>%s' %sfmt, buf[j0: j0+bytlen], order='F').copy()
-                    data = np.squeeze(data[2:])
+                    meta.dmin = data[0]
+                    meta.dmax = data[1]
+                    data = np.squeeze(data[2:]) # no array if n_items=1
                 dj0 = 8 * ( (bytlen + 7)//8 )
                 j0 += dj0
             else: # faulty dfmt
@@ -640,5 +656,5 @@ class SFREAD:
         otyp = sfo.obj_type
         if otyp != SignalGroup:
             return False
-        
+
         return (self.time_dim(obj) == sfo.num_dims-1)
